==> react-common-bootstrap-2.0.6.tgz: package/form/CustomFormField.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useRef } from 'react';
import { useFormContext } from './CustomForm';
import CustomFormFieldSelect from './CustomFormFieldSelect';
const CustomFormField = ({
  label = null,
  fieldName = '',
  value,
  onChange = null,
  type = 'text',
  className = '',
  name = '',
  disabled = false,
  isValid = true,
  feedback = '',
  options = null,
  emptySelectOption = false,
  prefix = null,
  suffix = null,
  placeholder = '',
  fileSizeLimit = 2097152,
  hint = '',
  multi = false,
  ...props
}, ref) => {
  const {
    displayError,
    formFields,
    setFormFields,
    setFormField
  } = useFormContext();
  const formValue = fieldName != '' ? formFields[fieldName] : value;
  const handleChange = value => {
    if (fieldName != '' && onChange == null) setFormField(fieldName, value);else if (onChange != null) onChange(value);
  };
  const renderFileInput = () => {
    const fileRef = useRef();
    return /*#__PURE__*/React.createElement("input", _extends({
      className: `form-control ${displayError && !isValid && 'is-invalid'}`,
      type: "file",
      ref: fileRef,
      onChange: _ => {
        if (fileRef.current.files[0].size < fileSizeLimit) {
          handleChange(fileRef.current.files);
        } else {
          alert('Le fichier est trop volumineux');
          fileRef.current.value = '';
        }
      },
      disabled: disabled
    }, props));
  };
  const renderTextarea = () => /*#__PURE__*/React.createElement("textarea", _extends({
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: formValue,
    onChange: e => handleChange(e.target.value),
    disabled: disabled,
    name: name,
    placeholder: placeholder,
    ref: ref
  }, props));
  const renderSelect = () => {
    return /*#__PURE__*/React.createElement(CustomFormFieldSelect, _extends({}, props, {
      label: label,
      className: `form-control ${displayError && !isValid && 'is-invalid'}`,
      value: formValue,
      onChange: onChange,
      fieldName: fieldName,
      setFormField: setFormField,
      name: name,
      disabled: disabled,
      placeholder: placeholder,
      ref: ref,
      options: emptySelectOption ? [{
        value: '',
        label: ''
      }, ...options] : options,
      multi: multi,
      isValid: isValid
    }));
  };
  const renderRadio = () => {
    const radioName = Math.random() * 1000;
    return /*#__PURE__*/React.createElement("div", {
      className: `radios-container spaced-inline ${className}`
    }, options.map(({
      value: radioValue,
      label
    }, index) => {
      const radioId = Math.random() * 1000;
      return /*#__PURE__*/React.createElement("div", {
        className: "radio spaced-inline",
        key: index
      }, /*#__PURE__*/React.createElement("input", {
        type: "radio",
        name: radioName,
        value: radioValue,
        checked: radioValue === formValue,
        id: radioId,
        onChange: e => handleChange(e.target.value),
        ref: ref
      }), /*#__PURE__*/React.createElement("label", {
        htmlFor: radioId
      }, label));
    }));
  };
  const renderInput = () => /*#__PURE__*/React.createElement("input", _extends({}, props, {
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: formValue,
    onChange: e => handleChange(e.target.value),
    type: type,
    name: name,
    disabled: disabled,
    placeholder: placeholder,
    ref: ref
  }));
  const renderCheckbox = () => /*#__PURE__*/React.createElement("div", {
    className: "form-group form-check custom-checkbox"
  }, /*#__PURE__*/React.createElement("input", _extends({}, props, {
    className: `form-check-input ${displayError && !isValid && 'is-invalid'}`,
    checked: formValue,
    onChange: e => handleChange(e.target.checked),
    type: "checkbox",
    name: name,
    disabled: disabled,
    ref: ref
  })), /*#__PURE__*/React.createElement("label", {
    className: "form-check-label"
  }, label));
  return /*#__PURE__*/React.createElement("div", {
    className: `custom-form-field ${className}`
  }, label != null && type != 'checkbox' && /*#__PURE__*/React.createElement("label", null, typeof label === 'function' ? label() : label), type === 'select' ? renderSelect() : /*#__PURE__*/React.createElement("div", {
    className: "input-group"
  }, prefix != null && /*#__PURE__*/React.createElement(React.Fragment, null, typeof prefix === 'function' ? prefix() : /*#__PURE__*/React.createElement("span", {
    className: "input-group-text"
  }, prefix)), type === 'textarea' ? renderTextarea() : type === 'checkbox' ? renderCheckbox() : type === 'file' ? renderFileInput() : type === 'radio' ? renderRadio() : renderInput(), suffix != null && /*#__PURE__*/React.createElement(React.Fragment, null, typeof suffix === 'function' ? suffix() : /*#__PURE__*/React.createElement("span", {
    className: "input-group-text"
  }, suffix)), displayError && !isValid && feedback != '' && /*#__PURE__*/React.createElement("div", {
    className: "invalid-feedback"
  }, feedback)), hint != '' && /*#__PURE__*/React.createElement("small", null, hint));
};
export default /*#__PURE__*/React.forwardRef(CustomFormField);

==> react-common-bootstrap-2.0.7.tgz: package/form/CustomFormField.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useRef } from 'react';
import { useFormContext } from './CustomForm';
import CustomFormFieldSelect from './CustomFormFieldSelect';
const CustomFormField = ({
  label = null,
  fieldName = '',
  value,
  onChange = null,
  type = 'text',
  className = '',
  name = '',
  disabled = false,
  isValid = true,
  feedback = '',
  options = null,
  emptySelectOption = false,
  prefix = null,
  suffix = null,
  placeholder = '',
  fileSizeLimit = 2097152,
  hint = '',
  multi = false,
  ...props
}, ref) => {
  const {
    displayError,
    formFields,
    setFormFields,
    setFormField
  } = useFormContext();
  const formValue = fieldName != '' ? formFields[fieldName] : value;
  const handleChange = value => {
    if (fieldName != '' && onChange == null) setFormField(fieldName, value);else if (onChange != null) onChange(value);
  };
  const renderFileInput = () => {
    const fileRef = useRef();
    return /*#__PURE__*/React.createElement("input", _extends({
      className: `form-control ${displayError && !isValid && 'is-invalid'}`,
      type: "file",
      ref: fileRef,
      onChange: _ => {
        if (fileRef.current.files[0].size < fileSizeLimit) {
          handleChange(fileRef.current.files);
        } else {
          alert('Le fichier est trop volumineux');
          fileRef.current.value = '';
        }
      },
      disabled: disabled
    }, props));
  };
  const renderTextarea = () => /*#__PURE__*/React.createElement("textarea", _extends({
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: formValue,
    onChange: e => handleChange(e.target.value),
    disabled: disabled,
    name: name,
    placeholder: placeholder,
    ref: ref
  }, props));
  const renderSelect = () => {
    return /*#__PURE__*/React.createElement(CustomFormFieldSelect, _extends({}, props, {
      label: label,
      className: `${displayError && !isValid && 'is-invalid'}`,
      value: formValue,
      onChange: onChange,
      fieldName: fieldName,
      setFormField: setFormField,
      name: name,
      disabled: disabled,
      placeholder: placeholder,
      ref: ref,
      options: emptySelectOption ? [{
        value: '',
        label: ''
      }, ...options] : options,
      multi: multi,
      isValid: isValid
    }));
  };
  const renderRadio = () => {
    const radioName = Math.random() * 1000;
    return /*#__PURE__*/React.createElement("div", {
      className: `radios-container spaced-inline ${className}`
    }, options.map(({
      value: radioValue,
      label
    }, index) => {
      const radioId = Math.random() * 1000;
      return /*#__PURE__*/React.createElement("div", {
        className: "radio spaced-inline",
        key: index
      }, /*#__PURE__*/React.createElement("input", {
        type: "radio",
        name: radioName,
        value: radioValue,
        checked: radioValue === formValue,
        id: radioId,
        onChange: e => handleChange(e.target.value),
        ref: ref
      }), /*#__PURE__*/React.createElement("label", {
        htmlFor: radioId
      }, label));
    }));
  };
  const renderInput = () => /*#__PURE__*/React.createElement("input", _extends({}, props, {
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: formValue,
    onChange: e => handleChange(e.target.value),
    type: type,
    name: name,
    disabled: disabled,
    placeholder: placeholder,
    ref: ref
  }));
  const renderCheckbox = () => /*#__PURE__*/React.createElement("div", {
    className: "form-group form-check custom-checkbox"
  }, /*#__PURE__*/React.createElement("input", _extends({}, props, {
    className: `form-check-input ${displayError && !isValid && 'is-invalid'}`,
    checked: formValue,
    onChange: e => handleChange(e.target.checked),
    type: "checkbox",
    name: name,
    disabled: disabled,
    ref: ref
  })), /*#__PURE__*/React.createElement("label", {
    className: "form-check-label"
  }, label));
  return /*#__PURE__*/React.createElement("div", {
    className: `custom-form-field ${className}`
  }, label != null && type != 'checkbox' && /*#__PURE__*/React.createElement("label", null, typeof label === 'function' ? label() : label), /*#__PURE__*/React.createElement("div", {
    className: "input-group"
  }, prefix != null && /*#__PURE__*/React.createElement(React.Fragment, null, typeof prefix === 'function' ? prefix() : /*#__PURE__*/React.createElement("span", {
    className: "input-group-text"
  }, prefix)), type === 'select' ? renderSelect() : type === 'textarea' ? renderTextarea() : type === 'checkbox' ? renderCheckbox() : type === 'file' ? renderFileInput() : type === 'radio' ? renderRadio() : renderInput(), suffix != null && /*#__PURE__*/React.createElement(React.Fragment, null, typeof suffix === 'function' ? suffix() : /*#__PURE__*/React.createElement("span", {
    className: "input-group-text"
  }, suffix)), displayError && !isValid && feedback != '' && /*#__PURE__*/React.createElement("div", {
    className: "invalid-feedback"
  }, feedback)), hint != '' && /*#__PURE__*/React.createElement("small", null, hint));
};
export default /*#__PURE__*/React.forwardRef(CustomFormField);
